# Octagon
> 8 fantastic sides and 8 awesome angles

[![](https://img.shields.io/github/workflow/status/Cloud11665/Octagon/Python%20application)](https://github.com/Cloud11665/Octagon/actions)
[![](https://img.shields.io/codefactor/grade/github/Cloud11665/Octagon)](https://www.codefactor.io/repository/github/cloud11665/octagon)
[![](https://img.shields.io/github/license/Cloud11665/Octagon)](https://github.com/Cloud11665/Octagon/blob/master/LICENSE)
[![](https://img.shields.io/pypi/v/Octagon)](https://pypi.org/project/Octagon)
[![](https://img.shields.io/pypi/pyversions/Octagon)](https://pypi.org/project/Octagon)

<img src="https://raw.githubusercontent.com/Cloud11665/Octagon/master/src/img/output.png" width=700px>

## Installation

OS X & Linux:
```sh
python3 -m pip install octagon
```
Windows:
```sh
pip install octagon
```

## Usage
```sh
-d, --debug               #Debug mode, shows the process of edge detection.
--nogui                   #FLAG, doesn't show the default gui.
-w, --webcam              #FLAG, can only choose one.
--wres INT INT            #Size of output, <x, y>, defaults to 640x480px
--wid INT                 #webcam ID, defaults to 0
--fps INT                 #Webcam FPS, defaults to 10
-i, --img PATH            #Input image path.
-v, --video PATH          #Input video path.
-o, --out PATH            #Output path.
-s, --scale FLOAT         #Gui scale.
--help                    #Show this message and exit.
```

## Meta

Your Name – [@Cloud11665](https://twitter.com/Cloud11665) – Cloud11665@gmail.com

Distributed under the GPL-3.0 license. See ``LICENSE`` for more information.

[https://github.com/Cloud11665/Octagon](https://github.com/Cloud11665/)

## Contributing

1. Fork it (<https://github.com/Cloud11665/Octagon/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request
